@@ -30,20 +30,27 @@ A Sphinx directive to specify that a module has extra requirements, and show how
 #
 
 # stdlib
+import sys
 from typing import Any, Dict
 
+# This all has to be up here so it's triggered first.
+if sys.version_info >= (3, 10):
+	# stdlib
+	import types
+	types.Union = types.UnionType
+
 # 3rd party
 from sphinx.application import Sphinx
 
 # this package
 from sphinxcontrib.extras_require.directive import ExtrasRequireDirective
 from sphinxcontrib.extras_require.purger import extras_require_purger
-from sphinxcontrib.extras_require.sources import sources
+from sphinxcontrib.extras_require.sources import sources  # noqa: F401
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "BSD"
-__version__: str = "0.4.0"
+__version__: str = "0.4.2"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["extras_require_purger", "setup"]
